@@ -1,7 +1,9 @@
+"""SoaM workflow."""
 from soam.workflow.backtester import Backtester, compute_metrics
 from soam.workflow.forecaster import Forecaster
 from soam.workflow.merge_concat import MergeConcat
 from soam.workflow.slicer import Slicer
+from soam.workflow.store import Store
 from soam.workflow.time_series_extractor import TimeSeriesExtractor
 import soam.workflow.transformer
 from soam.workflow.transformer import (
