@@ -26,7 +26,8 @@ class Forecaster(Step):
         response_col: str = Y_COL,
         **kwargs,
     ):
-        """Wrap a forecasting model to run it inside a pipeline.
+        """
+        Wrap a forecasting model to run it inside a pipeline.
 
         Parameters
         ----------
@@ -80,14 +81,17 @@ class Forecaster(Step):
 
         X_train = X[: -self.output_length]
         X_pred = X[-self.output_length :]
-        self.model.fit(X_train, y)
+        y_train = y[: -self.output_length]
+
+        self.model.fit(X_train, y_train)
         self.prediction = self.model.predict(X_pred)
         return self.prediction, self.time_series, self.model
 
     def _format_input(
         self, time_series: pd.DataFrame
     ) -> Tuple[pd.DataFrame, pd.Series]:
-        """Transform time series DataFrame into SoaM compatible format.
+        """
+        Transform time series DataFrame into SoaM compatible format.
 
         Parameters
         ----------
