@@ -1,4 +1,5 @@
-"""Module to extract and aggregate time series.
+"""
+Module to extract and aggregate time series.
 
 # General TODOs:
 - Make quantiles great again:
@@ -11,7 +12,8 @@ Notes:
     joining higher in the hierarchy.
 - It would be interesting to implement unique counts.
 
-[1] Ralph Kimball, Margy Ross - The Data Warehouse Toolkit (2013)."""
+[1] Ralph Kimball, Margy Ross - The Data Warehouse Toolkit (2013).
+"""
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
 
 from jinja2 import Template
@@ -27,6 +29,7 @@ from soam.core import Step
 
 if TYPE_CHECKING:
     import datetime as dt
+
     import muttlib
 
 # Simple column selection templates.
@@ -62,7 +65,8 @@ class TimeSeriesExtractor(Step):
         table_name: str,
         **kwargs: Dict[str, Any],
     ):
-        """Class to handle the dataset retrieval from the PostgreSql database.
+        """
+        Class to handle the dataset retrieval from the PostgreSql database.
 
         Parameters
         ----------
@@ -77,7 +81,8 @@ class TimeSeriesExtractor(Step):
         self.table_name = table_name
 
     def extract(self, build_query_kwargs: Dict[str, Any],) -> pd.DataFrame:
-        """Extracts aggregated data and return it as a pandas DataFrame.
+        """
+        Extracts aggregated data and return it as a pandas DataFrame.
 
         Parameters
         ----------
@@ -100,6 +105,7 @@ class TimeSeriesExtractor(Step):
     # maybe define class type all this arguments?
     def build_query(
         self,
+        table_mapping: str = None,
         columns=None,
         prequery: str = "",
         dimensions: List[str] = None,
@@ -114,10 +120,13 @@ class TimeSeriesExtractor(Step):
         aggregated_column_mappings: Dict = None,
         inner_join: Optional[List[Tuple[str, str, str]]] = None,
     ) -> Tuple[str, Dict[str, Any]]:
-        """Build the query to extract and aggregated dataset.
+        """
+        Build the query to extract and aggregated dataset.
 
         Parameters
         ----------
+        table_mapping: str
+            The alias of the table.
         columns: list of str
             The columns to retrieve.
         prequery: str
@@ -157,7 +166,10 @@ class TimeSeriesExtractor(Step):
             A list of conditions to be added to the "where" clause.
         extra_having_conditions:  list of str or None
             A list of conditions to be added to the "having" clause.
-        column_mappings: TODO: missing doc
+        column_mappings: dict
+            A dict with 'column names' as keys and 'column as column alias' as values.
+            E.g.: A dict like {'date':'date as fecha'} would result in
+            a SQL statement 'SELECT date as fecha'.
         aggregated_column_mappings: dict
             Contains the aggregation functions and aliases to replace the column
             values.
@@ -186,6 +198,9 @@ class TimeSeriesExtractor(Step):
           {{ prequery }}
           SELECT {{ columns | join(", ") }}
           FROM {{ table_name }}
+          {% if table_mapping %}
+          AS {{ table_mapping }}
+          {% endif %}
           {% if join_tables %}
           {% for j_table in join_tables %}
           INNER JOIN {{ j_table.0 }}
@@ -219,6 +234,7 @@ class TimeSeriesExtractor(Step):
             "prequery": prequery,
             "columns": "*",
             "table_name": self.table_name,
+            "table_mapping": table_mapping,
             "join_tables": inner_join,
             "where": "",
             "group_by": "",
@@ -254,6 +270,11 @@ class TimeSeriesExtractor(Step):
         kwargs.update(date_kwargs)
         where_conds.extend(date_conds)
         if extra_where_conditions:
+            extra_where_conditions = [
+                cond.replace("%", "%%")
+                for cond in extra_where_conditions
+                if "%" in cond
+            ]
             where_conds.extend(extra_where_conditions)
         if where_conds:
             placeholders["where"] = where_conds  # type: ignore
@@ -295,7 +316,8 @@ class TimeSeriesExtractor(Step):
         end_date=None,
         order_by=None,
     ):
-        """Returns the values for the dimensions provided in the dataset.
+        """
+        Returns the values for the dimensions provided in the dataset.
 
         Parameters
         ----------
@@ -379,7 +401,8 @@ class TimeSeriesExtractor(Step):
     def _filter_date_range(
         self, start_date=None, end_date=None, timestamp_col=TIMESTAMP_COL,
     ):
-        """Returns a list of conditions for a where clause and a dictionary
+        """
+        Returns a list of conditions for a where clause and a dictionary
         with keyword arguments to fill the conditions parameters.
 
         Parameters
@@ -411,7 +434,8 @@ class TimeSeriesExtractor(Step):
         return conds, kwargs
 
     def _negate_dimensions(self, dimensions):
-        """Returns dimensions without the prefix symbols and a boolean list
+        """
+        Returns dimensions without the prefix symbols and a boolean list
         indication if they have to be negated.
 
         Parameters
@@ -429,7 +453,8 @@ class TimeSeriesExtractor(Step):
         return self._detect_dimensions_prefix_symbol(dimensions, NEGATE_SYMBOL)
 
     def _dont_aggregate_dimensions(self, dimensions):
-        """Returns dimensions without the prefix symbols and a boolean list
+        """
+        Returns dimensions without the prefix symbols and a boolean list
         indication if they don't have to be aggregated.
 
         Parameters
@@ -449,7 +474,8 @@ class TimeSeriesExtractor(Step):
     def _detect_dimensions_prefix_symbol(
         self, dimensions, prefix_symbol,
     ):
-        """Returns dimensions with the prefix symbols removed and a boolean
+        """
+        Returns dimensions with the prefix symbols removed and a boolean
         list indication if they are prefixed with it.
 
         Parameters
@@ -484,7 +510,8 @@ class TimeSeriesExtractor(Step):
     def _filter_dimensions_values(
         self, dimensions, dimensions_values, negate_dimensions_values,
     ):
-        """Returns a list of conditions for a where clause and a dictionary
+        """
+        Returns a list of conditions for a where clause and a dictionary
         with keyword arguments to fill the conditions parameters.
 
         Parameters
@@ -523,4 +550,16 @@ class TimeSeriesExtractor(Step):
         return conds, kwargs
 
     def run(self, build_query_kwargs: Dict[str, Any]) -> pd.DataFrame:  # type: ignore
+        """
+        Returns aggregated data from a query into a pandas DataFrame.
+
+        Parameters
+        ----------
+        build_query_kwargs: dict
+
+        Returns
+        -------
+        pd.DataFrame
+            Agregated data from the time series extractor object.
+        """
         return self.extract(build_query_kwargs)
