@@ -1,3 +1,4 @@
+"""Integration test module."""
 from copy import deepcopy
 
 import pandas as pd
@@ -13,7 +14,7 @@ from soam.constants import (
     YHAT_COL,
 )
 from soam.core import SoamFlow
-from soam.models import SkProphet
+from soam.models.prophet import SkProphet
 from soam.plotting import ForecastPlotterTask
 from soam.reporting import SlackReportTask
 from soam.reporting.slack_report import (
@@ -39,6 +40,7 @@ def create_slack_message(
     farewell_message=DEFAULT_FAREWELL_MESSAGE,
     greeting_message=DEFAULT_GREETING_MESSAGE,
 ):
+    """Function to create the slack message."""
     greeting_message.format(metric_name=metric)
 
     summary_entries = []
@@ -54,6 +56,7 @@ def create_slack_message(
 
 
 def create_settings_file(path, content):
+    """Function to acquire the settings file path."""
     # Code to acquire resource, e.g.:
     setting_path = path / "settings.ini"
     with open(setting_path, "w+") as f:
